@@ -36,7 +36,7 @@ start: (instruction | _NEWLINE | COMMENT)+
 instruction: run | copy | from | disk | partition | add | inspect
 run: "RUN"i run_body _NEWLINE
 run_body: RUN_CMD+
-RUN_CMD: /[^\\\n]/+
+RUN_CMD: /(\\[^ \t\n])|[^\\\n]/+
 
 copy: "COPY"i copy_source+ copy_destination _NEWLINE
 copy_source: PATH
@@ -90,9 +90,9 @@ class GuestChrootCommand(editor.GuestCommand):
         capture_stdout: bool = False,
         capture_stderr: bool = False,
     ):
-        escaped_command = cmd.replace("'", "'\\''")
+        escaped_command = cmd.replace("'", r"'\''")
         chroot_command = (
-            f"""unshare --fork --pid chroot /mnt /bin/bash -c '{escaped_command}' """
+            f"""unshare --fork --pid chroot /mnt /bin/sh -c '{escaped_command}' """
         )
         super().__init__(
             chroot_command,
@@ -280,18 +280,21 @@ class PartitionInstruction(ImageInstruction):
         if self.size is not None:
             partition_cmd += f"size={self.size}{self.units},"
 
+        has_type = False
         if self.flags is not None:
             for flag in self.flags:
                 if flag == "boot":
                     partition_cmd += "bootable,"
                 elif flag == "efi":
                     partition_cmd += "type=U,"
+                    has_type = True
                 elif flag == "bios_grub":
                     # The BIOS boot GPT GUID
                     partition_cmd += "type=21686148-6449-6E6F-744E-656564454649,"
+                    has_type = True
 
         # Mark anything that doesn't have an explicit type as Linux
-        if partition_cmd == "":
+        if has_type is False:
             partition_cmd += "type=L,"
 
         commands = [
@@ -513,9 +516,7 @@ class ImageBuilder:
         config = self.editor.ssh_config.override(
             args=[*self.editor.ssh_config.args, "-t"]
         )
-        client = ssh.SshClient(
-            config, command="unshare --fork --pid chroot /mnt /bin/bash"
-        )
+        client = ssh.SshClient(config, command="unshare --fork --pid chroot /mnt /bin/sh")
 
         # Connect everything normally
         handle = client.connect(
