@@ -50,6 +50,9 @@ _ssh_options = [
     click.option(
         "-ssh-command", "-cmd", type=str, help="Run an ssh command instead of a console",
     ),
+    click.option(
+        "-ssh-option", "-o", multiple=True, type=str, help="Pass an option to SSH",
+    ),
 ]
 
 
@@ -150,6 +153,9 @@ def cli_entry(verbose: int) -> None:
     help="Copy a file or directory out of the VM after running "
     + "(/absolute/path/on/VM:path/on/host)",
 )
+@click.option(
+    "-rsync", is_flag=True, help="Use rsync for copy-in-before/copy-out-after operations"
+)
 @click.option("-name", type=str, help="Create a vm with the given name")
 @click.option(
     "-ssh-console",
@@ -235,9 +241,9 @@ def run_impl(**kwargs: Any) -> None:
     try:
         trans.run()
         sys.exit(0)
-    except utils.TransientProcessError as e:
+    except utils.TransientError as e:
         print(e, file=sys.stderr)
-        sys.exit(e.returncode)
+        e.exit()
 
 
 @click.help_option("-h", "--help")
@@ -337,6 +343,7 @@ def ssh_impl(**kwargs: Any) -> None:
         user=config.ssh_user,
         ssh_bin_name=config.ssh_bin_name,
         port=instance.ssh_port,
+        extra_options=config.ssh_option,
     )
     client = ssh.SshClient(config=ssh_config, command=config.ssh_command)
     connection = client.connect_stdout(config.ssh_timeout)
